@@ -283,6 +283,56 @@ int encoder_reduced_binary::compute_params(const uint16_t *data,
   return 0;
 }
 
+//----------------------------------------------------------------------
+/// Compute the parameters needed for the encoding algorithm.
+/// Here assume that the max/min of the data to be encoded is the
+/// range that needs to be encoded without an Overflow.
+/// \param data  Array of data to be analyzed (can be a statistical sample).
+/// \param ndata Length of data array.
+/// \return Error code, or 0=no error.
+int encoder_reduced_binary::compute_params(const uint8_t *data, 
+                                           const int ndata) {
+  assert (data_type == SLIM_TYPE_I8 ||
+          data_type == SLIM_TYPE_U8);
+
+  const int8_t *sdata = 
+    reinterpret_cast<const int8_t *>(data);
+
+  // Estimate mean of the data
+  double avg;
+  if (data_type == SLIM_TYPE_I8) {
+    compute_mean(avg, sdata, ndata);
+    offset = (uint8_t)(nearbyint(avg));
+  } else {
+    compute_mean(avg, data, ndata);
+    offset = (uint8_t)(nearbyint(avg));
+  }
+
+  int histogram[33]={0};
+  uint32_t set_bits=0;
+  for (int i=0; i<ndata; i++) {
+    histogram[bit_size((int8_t)(data[i]-offset))]++;
+    set_bits |= data[i];
+  }
+  nbits = best_code_length(histogram, ndata);
+
+  if (nbits > data_size_bits)
+    nbits = data_size_bits;
+  if (nbits < 1u)
+    nbits = 1u;
+  
+  // We found assuming integer data and offset = avg in middle of range.
+  // But we _want_ unsigned data and offset at the bottom of range.
+  if (nbits > 1)
+    offset -= 1 << (nbits-1u);
+
+  // set Overflow to the largest nbits-bit number
+  Overflow = lowestNset[nbits];
+  max = Overflow-1;
+
+  return 0;
+}
+
 
 
 //----------------------------------------------------------------------
@@ -401,6 +451,25 @@ uint16_t decoder_reduced_binary::decode_u16()
 
 
 
+//----------------------------------------------------------------------
+/// Decode one word from the input stream.
+/// \return  The decoded word.
+uint8_t decoder_reduced_binary::decode_u8() 
+{
+  uint8_t datum;
+  try {
+    datum = in_bs->readbits(nbits);
+    if (datum == Overflow) {
+      return in_bs->readbits(data_size_bits);
+    } else
+      return datum+offset;
+  } catch (const char * s) { // This catches end of input.
+    return 0;
+  }
+}
+
+
+
 //----------------------------------------------------------------------
 /// Write decoder parameters to a stream.
 /// \param fout  The writeable output stream.
