@@ -35,7 +35,7 @@
 
 
 /// Single-character options
-const char short_opt[] = "m:c:r:F:dnpXxSC0bPokquivsfg987654321V?B:";
+const char short_opt[] = "m:c:r:F:dnpXxSC0bPokquivsyfg987654321V?B:";
 
 /// The long options slim recognizes.
 const static struct option long_opt[] = {
@@ -110,31 +110,31 @@ void slim_control::slimcat() {
 
 
 /// Parse command-line arguments.
-/// \param argc Number of tokens in command line. 
+/// \param argc Number of tokens in command line.
 /// \param argv Array of ptr to these tokens.
-void slim_control::process_args(int argc, char * const argv[]) 
+void slim_control::process_args(int argc, char * const argv[])
 {
   bool print_version=false, print_help=false;
   const int END_OF_OPTIONS = -1;
 
-  //cout << "Processing "<<argc<<" arguments"<<endl;
+  // cout << "Processing "<<argc<<" arguments"<<endl;
   for (opterr = 0;;) {
     int longindex=0;
     int curind = optind;
     int c = getopt_long(argc, argv, short_opt, long_opt, &longindex);
-    //cout << "Working with optind="<<curind<<" and c="<<c<<endl;
+    // cout << "Working with optind="<<curind<<" and c="<<c<<endl;
     if (c == END_OF_OPTIONS)
       break;
 
-    //cout <<"Processed option #"<<longindex<<" which is ascii("<<c<<")='"
-    //<<char(c) <<"'"<<endl;
+    // cout <<"Processed option #"<<longindex<<" which is ascii("<<c<<")='"
+    // <<char(c) <<"'"<<endl;
     switch (c) {
     case 0:
       if (strncmp(long_opt[longindex].name, "help",
 		   strlen(long_opt[longindex].name))==0)
 	usage();
       break;
-      
+
     case 'm':
       code_method = (enum code_t)(atoi(optarg));
       break;
@@ -287,15 +287,15 @@ void slim_control::usage() const {
   cout << "usage: unslim  [options] filename ...\n";
   cout << "usage: slimcat [options] filename ...\n";
   cout << "Allowed options are:\n";
-  
+
   usage_printoptions();
 }
 
 
 /// Print the options portion of a usage message.
 void slim_control::usage_printoptions() const {
-  const char noarg[]="", 
-    hasarg[]="<arg required>", 
+  const char noarg[]="",
+    hasarg[]="<arg required>",
     optional[]="[arg optional]";
   const char *argval[3]={noarg, hasarg, optional};
 
@@ -313,13 +313,13 @@ void slim_control::usage_printoptions() const {
 
 
 /// Print version message.
-void slim_control::version() const 
+void slim_control::version() const
 {
   string versionstr=SLIM_VERSION;
   if (versionstr[0] == ' ')
     cout << "This is slim, the physics data compressor, untagged version.\n";
   else {
-    cout << "This is slim, the physics data compressor, version " 
+    cout << "This is slim, the physics data compressor, version "
          << versionstr << ".\n";
   }
 }
@@ -388,7 +388,7 @@ char slim_control::flags(char in)
   onechan =       in & FLAG_ONECHAN;
   noreps =        in & FLAG_NOREPS;
   crc =           in & FLAG_CRC;
-  
+
   return in;
 }
 
@@ -447,7 +447,7 @@ void slim_control::handle_one_file(const char *fname)
     else {
       debug_compress_from_memory(fname);
     }
-  } 
+  }
 
   if (thismode == SLIM_DECODE) {
     if (debug_buf_size == 0)
@@ -462,7 +462,7 @@ void slim_control::handle_one_file(const char *fname)
 /// Compress one file using slim_compressor_t::compress_from_file()
 /// \param rawname  The name of the file to be encoded.
 void slim_control::compress_one_file(const char *rawname) {
-  
+
   // Verify that file exists
   struct stat st;
   int ret = stat(rawname, &st);
@@ -484,7 +484,7 @@ void slim_control::compress_one_file(const char *rawname) {
 
   slim_compressor_t *compressor =
     new slim_compressor_t(outname, flags(), deltas, sample_pct);
-  
+
   // If no cmd-line indications, just let there be 1 frame,
   // and all data go in multiple repeats within that section and frame.
   int repeats_thisfile = repeats, nframes_thisfile = nframes;
@@ -492,7 +492,7 @@ void slim_control::compress_one_file(const char *rawname) {
     repeats_thisfile = raw_file_size/(sizeof(int)*nchan);
     nframes_thisfile = 1;
   } else if (nframes <= 0) {
-    if (repeats == 1) 
+    if (repeats == 1)
       nframes_thisfile =  divide_round_up(raw_file_size, sizeof(int)*nchan);
     else
       nframes_thisfile = 1;
@@ -505,13 +505,13 @@ void slim_control::compress_one_file(const char *rawname) {
   if (nchan == 1) {
     if (nframes_thisfile > 1)
       repeats_thisfile *= nframes_thisfile;
-    nframes_thisfile = divide_round_up(repeats_thisfile, 
+    nframes_thisfile = divide_round_up(repeats_thisfile,
                                        MAX_SECTION_LENGTH / sizeof(int));
     if (nframes_thisfile > 1)
       repeats_thisfile = MAX_SECTION_LENGTH / sizeof(int);
   }
   noreps = (repeats_thisfile == 1);
-    
+
   // Build the channel list
   for (int i=0; i<nchan; i++)
     compressor->add_channel(repeats_thisfile, code_method, data_type,
@@ -529,7 +529,7 @@ void slim_control::compress_one_file(const char *rawname) {
   if (ret1 || ret2) return;
   if (!force_clobber && (st_raw.st_size <= st_out.st_size)) {
     if (!quiet)
-      cerr << "slim: " << rawname << 
+      cerr << "slim: " << rawname <<
         " expanded when slimmed (use -k to force).\n";
     unlink(outname);
   } else if (practice) {
@@ -544,7 +544,7 @@ void slim_control::compress_one_file(const char *rawname) {
 /// Expand one compressed file using slim_expander_t::expand_to_file().
 /// \param compname  The name of the file to be decoded.
 void slim_control::expand_one_file(const char *compname) {
- 
+
   // Verify that file exists
   struct stat st;
   int ret = stat(compname, &st);
@@ -624,7 +624,7 @@ void slim_control::expand_one_file(const char *compname) {
 /// Compress a single file using slim_compressor_t::write() to test that code.
 /// \param rawname  The path of the file to be compressed.
 void slim_control::debug_compress_from_memory(const char *rawname) {
-  
+
   // Verify that file exists
   struct stat st;
   stat(rawname, &st);
@@ -643,7 +643,7 @@ void slim_control::debug_compress_from_memory(const char *rawname) {
     new slim_compressor_t(outname.c_str(), flags(), deltas, sample_pct);
   compressor->mtime = st.st_mtime;
   compressor->raw_size = st.st_size;
-  
+
   // If no cmd-line indications, just let there be 1 frame, 1 section,
   // and all data go in multiple repeats within that section and frame.
   int repeats_thisfile = repeats;
@@ -651,7 +651,7 @@ void slim_control::debug_compress_from_memory(const char *rawname) {
     repeats_thisfile = raw_file_size/sizeof(int);
     nframes = 1;
   } else if (nframes <= 0) {
-    if (repeats == 1) 
+    if (repeats == 1)
       nframes = INT_MAX;
     else
       nframes = 1;
