@@ -826,7 +826,7 @@ int slim_compressor_t::compress_from_file(const char *raw_file_name) {
     }
     int num_sect = divide_round_up(raw_size, frame_size*max_frames_per_section);
     num_sect *= breakup_factor;
-    int frames_this_sect = num_frames;
+    int frames_this_sect;
     int frames_written = 0;
 
     // Loop over all sections in the output
@@ -862,7 +862,7 @@ int slim_compressor_t::compress_from_file(const char *raw_file_name) {
   alter_mtime(out_filename, mtime);
   
   // Report on the compression ratio
-  {
+  if (!quiet) {
     struct stat status;
     stat(out_filename, &status);
     size_t final_size = status.st_size;
@@ -1376,18 +1376,20 @@ int slim_expander_t::expand_to_file(const char *raw_filename) {
   FILE *fp = fopen(raw_filename, "wb");
   assert (fp != NULL);
 
-  cout.width(20);
-  cout << in_filename << ":\t";
-  if (raw_size) {
-    cout.width(6);
-    cout.precision(1);
-    ios_base::fmtflags old = cout.setf(ios_base::fixed, ios_base::floatfield);
-    cout << 100.*(1.-double(slim_size)/raw_size);
-    cout.setf(old, ios::floatfield);
+  if (!quiet) {
+    cout.width(20);
+    cout << in_filename << ":\t";
+    if (raw_size) {
+      cout.width(6);
+      cout.precision(1);
+      ios_base::fmtflags old = cout.setf(ios_base::fixed, ios_base::floatfield);
+      cout << 100.*(1.-double(slim_size)/raw_size);
+      cout.setf(old, ios::floatfield);
 
-  } else
-    cout << " ???? ";
-  cout << "% -- replacing with " << raw_filename << "\n";
+    } else
+      cout << " ???? ";
+    cout << "% -- replacing with " << raw_filename << "\n";
+  }
 
   // Loop over all sections, reading and writing them
   while (1) {
